==> SuiteCRM-8.2.3.zip: public/legacy/modules/Surveys/language/en_us.lang.php <==
<?php
/**
 *
 * SugarCRM Community Edition is a customer relationship management program developed by
 * SugarCRM, Inc. Copyright (C) 2004-2013 SugarCRM Inc.
 *
 * SuiteCRM is an extension to SugarCRM Community Edition developed by SalesAgility Ltd.
 * Copyright (C) 2011 - 2019 SalesAgility Ltd.
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Affero General Public License version 3 as published by the
 * Free Software Foundation with the addition of the following permission added
 * to Section 15 as permitted in Section 7(a): FOR ANY PART OF THE COVERED WORK
 * IN WHICH THE COPYRIGHT IS OWNED BY SUGARCRM, SUGARCRM DISCLAIMS THE WARRANTY
 * OF NON INFRINGEMENT OF THIRD PARTY RIGHTS.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Affero General Public License for more
 * details.
 *
 * You should have received a copy of the GNU Affero General Public License along with
 * this program; if not, see http://www.gnu.org/licenses or write to the Free
 * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301 USA.
 *
 * You can contact SugarCRM, Inc. headquarters at 10050 North Wolfe Road,
 * SW2-130, Cupertino, CA 95014, USA. or at email address contact@sugarcrm.com.
 *
 * The interactive user interfaces in modified source and object code versions
 * of this program must display Appropriate Legal Notices, as required under
 * Section 5 of the GNU Affero General Public License version 3.
 *
 * In accordance with Section 7(b) of the GNU Affero General Public License version 3,
 * these Appropriate Legal Notices must retain the display of the "Powered by
 * SugarCRM" logo and "Supercharged by SuiteCRM" logo. If the display of the logos is not
 * reasonably feasible for technical reasons, the Appropriate Legal Notices must
 * display the words "Powered by SugarCRM" and "Supercharged by SuiteCRM".
 */

$mod_strings = array(
    'LBL_ASSIGNED_TO_ID'                                     => 'Assigned User Id',
    'LBL_ASSIGNED_TO_NAME'                                   => 'Assigned to',
    'LBL_SECURITYGROUPS'                                     => 'Security Groups',
    'LBL_SECURITYGROUPS_SUBPANEL_TITLE'                      => 'Security Groups',
    'LBL_ID'                                                 => 'ID',
    'LBL_DATE_ENTERED'                                       => 'Date Created',
    'LBL_DATE_MODIFIED'                                      => 'Date Modified',
    'LBL_MODIFIED'                                           => 'Modified By',
    'LBL_MODIFIED_ID'                                        => 'Modified By Id',
    'LBL_MODIFIED_NAME'                                      => 'Modified By Name',
    'LBL_CREATED'                                            => 'Created By',
    'LBL_CREATED_ID'                                         => 'Created By Id',
    'LBL_DESCRIPTION'                                        => 'Description',
    'LBL_DELETED'                                            => 'Deleted',
    'LBL_NAME'                                               => 'Name',
    'LBL_CREATED_USER'                                       => 'Created by User',
    'LBL_MODIFIED_USER'                                      => 'Modified by User',
    'LBL_LIST_NAME'                                          => 'Name',
    'LBL_EDIT_BUTTON'                                        => 'Edit',
    'LBL_REMOVE'                                             => 'Remove',
    'LBL_LIST_FORM_TITLE'                                    => 'Surveys List',
    'LBL_MODULE_NAME'                                        => 'Surveys',
    'LBL_MODULE_TITLE'                                       => 'Surveys',
    'LBL_HOMEPAGE_TITLE'                                     => 'My Surveys',
    'LNK_NEW_RECORD'                                         => 'Create Surveys',
    'LNK_LIST'                                               => 'View Surveys',
    'LNK_IMPORT_SURVEYS'                                     => 'Import Surveys',
    'LBL_SEARCH_FORM_TITLE'                                  => 'Search Surveys',
    'LBL_HISTORY_SUBPANEL_TITLE'                             => 'View History',
    'LBL_ACTIVITIES_SUBPANEL_TITLE'                          => 'Activities',
    'LBL_SURVEYS_SUBPANEL_TITLE'                             => 'Surveys',
    'LBL_NEW_FORM_TITLE'                                     => 'New Surveys',
    'LBL_STATUS'                                             => 'Status',
    'LBL_SURVEY_QUESTIONS_DISPLAY'                           => 'Questions',
    'LBL_SURVEY_URL_DISPLAY'                                 => 'URL',
    'LBL_HAPPINESS_QUESTION'                                 => 'Happiness Question',
    'LBL_CANT_EDIT_RESPONDED'                                => 'Survey questions with responses cannot be edited',
    'LBL_VIEW_SURVEY_REPORTS'                                => 'View Survey Reports',
    'LBL_CHECKED'                                            => 'Checked',
    'LBL_UNCHECKED'                                          => 'Unchecked',
    'LBL_RESPONSE_ANSWER'                                    => 'Answer',
    'LBL_RESPONSE_CONTACT'                                   => 'Contact',
    'LBL_RESPONSE_TIME'                                      => 'Date',
    'LBL_UNKNOWN_CONTACT'                                    => 'Unknown',
    'LBL_RESPONSE_COUNT'                                     => 'Count',
    'LBL_SUBMIT_TEXT'                                        => 'Submit Text',
    'LBL_SATISFIED_TEXT'                                     => 'Satisfied Text',
    'LBL_NEITHER_TEXT'                                       => 'Neither Text',
    'LBL_DISSATISFIED_TEXT'                                  => 'Dissatisfied Text',
    'LBL_SURVEYS_SURVEYQUESTIONS_FROM_SURVEYQUESTIONS_TITLE' => 'Survey Questions',
    'LBL_SURVEYS_SURVEYRESPONSES_FROM_SURVEYRESPONSES_TITLE' => 'Survey Responses',
    'LBL_SHOW_RESPONSES' => 'Show responses',
    'LNK_LIST_SURVEY_RESPONSES' => 'Show Survey Responses',
);

==> SuiteCRM-8.3.0.zip: public/legacy/modules/Surveys/language/en_us.lang.php <==
<?php
/**
 *
 * SugarCRM Community Edition is a customer relationship management program developed by
 * SugarCRM, Inc. Copyright (C) 2004-2013 SugarCRM Inc.
 *
 * SuiteCRM is an extension to SugarCRM Community Edition developed by SalesAgility Ltd.
 * Copyright (C) 2011 - 2019 SalesAgility Ltd.
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Affero General Public License version 3 as published by the
 * Free Software Foundation with the addition of the following permission added
 * to Section 15 as permitted in Section 7(a): FOR ANY PART OF THE COVERED WORK
 * IN WHICH THE COPYRIGHT IS OWNED BY SUGARCRM, SUGARCRM DISCLAIMS THE WARRANTY
 * OF NON INFRINGEMENT OF THIRD PARTY RIGHTS.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Affero General Public License for more
 * details.
 *
 * You should have received a copy of the GNU Affero General Public License along with
 * this program; if not, see http://www.gnu.org/licenses or write to the Free
 * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301 USA.
 *
 * You can contact SugarCRM, Inc. headquarters at 10050 North Wolfe Road,
 * SW2-130, Cupertino, CA 95014, USA. or at email address contact@sugarcrm.com.
 *
 * The interactive user interfaces in modified source and object code versions
 * of this program must display Appropriate Legal Notices, as required under
 * Section 5 of the GNU Affero General Public License version 3.
 *
 * In accordance with Section 7(b) of the GNU Affero General Public License version 3,
 * these Appropriate Legal Notices must retain the display of the "Powered by
 * SugarCRM" logo and "Supercharged by SuiteCRM" logo. If the display of the logos is not
 * reasonably feasible for technical reasons, the Appropriate Legal Notices must
 * display the words "Powered by SugarCRM" and "Supercharged by SuiteCRM".
 */

$mod_strings = array(
    'LBL_ASSIGNED_TO_ID'                                     => 'Assigned User Id',
    'LBL_ASSIGNED_TO_NAME'                                   => 'Assigned to',
    'LBL_SECURITYGROUPS'                                     => 'Security Groups',
    'LBL_SECURITYGROUPS_SUBPANEL_TITLE'                      => 'Security Groups',
    'LBL_ID'                                                 => 'ID',
    'LBL_DATE_ENTERED'                                       => 'Date Created',
    'LBL_DATE_MODIFIED'                                      => 'Date Modified',
    'LBL_MODIFIED'                                           => 'Modified By',
    'LBL_MODIFIED_ID'                                        => 'Modified By Id',
    'LBL_MODIFIED_NAME'                                      => 'Modified By Name',
    'LBL_CREATED'                                            => 'Created By',
    'LBL_CREATED_ID'                                         => 'Created By Id',
    'LBL_DESCRIPTION'                                        => 'Description',
    'LBL_DELETED'                                            => 'Deleted',
    'LBL_NAME'                                               => 'Name',
    'LBL_CREATED_USER'                                       => 'Created by User',
    'LBL_MODIFIED_USER'                                      => 'Modified by User',
    'LBL_LIST_NAME'                                          => 'Name',
    'LBL_EDIT_BUTTON'                                        => 'Edit',
    'LBL_REMOVE'                                             => 'Remove',
    'LBL_LIST_FORM_TITLE'                                    => 'Surveys List',
    'LBL_MODULE_NAME'                                        => 'Surveys',
    'LBL_MODULE_TITLE'                                       => 'Surveys',
    'LBL_HOMEPAGE_TITLE'                                     => 'My Surveys',
    'LNK_NEW_RECORD'                                         => 'Create Surveys',
    'LNK_LIST'                                               => 'View Surveys',
    'LNK_IMPORT_SURVEYS'                                     => 'Import Surveys',
    'LBL_SEARCH_FORM_TITLE'                                  => 'Search Surveys',
    'LBL_HISTORY_SUBPANEL_TITLE'                             => 'View History',
    'LBL_ACTIVITIES_SUBPANEL_TITLE'                          => 'Activities',
    'LBL_SURVEYS_SUBPANEL_TITLE'                             => 'Surveys',
    'LBL_NEW_FORM_TITLE'                                     => 'New Surveys',
    'LBL_STATUS'                                             => 'Status',
    'LBL_SURVEY_QUESTIONS_DISPLAY'                           => 'Questions',
    'LBL_SURVEY_URL_DISPLAY'                                 => 'URL',
    'LBL_HAPPINESS_QUESTION'                                 => 'Happiness Question',
    'LBL_CANT_EDIT_RESPONDED'                                => 'Survey questions with responses cannot be edited',
    'LBL_VIEW_SURVEY_REPORTS'                                => 'View Survey Reports',
    'LBL_CHECKED'                                            => 'Checked',
    'LBL_UNCHECKED'                                          => 'Unchecked',
    'LBL_RESPONSE_ANSWER'                                    => 'Answer',
    'LBL_RESPONSE_CONTACT'                                   => 'Contact',
    'LBL_RESPONSE_TIME'                                      => 'Date',
    'LBL_UNKNOWN_CONTACT'                                    => 'Unknown',
    'LBL_RESPONSE_COUNT'                                     => 'Count',
    'LBL_SUBMIT_TEXT'                                        => 'Submit Text',
    'LBL_SATISFIED_TEXT'                                     => 'Satisfied Text',
    'LBL_NEITHER_TEXT'                                       => 'Neither Text',
    'LBL_DISSATISFIED_TEXT'                                  => 'Dissatisfied Text',
    'LBL_SURVEYS_SURVEYQUESTIONS_FROM_SURVEYQUESTIONS_TITLE' => 'Survey Questions',
    'LBL_SURVEYS_SURVEYRESPONSES_FROM_SURVEYRESPONSES_TITLE' => 'Survey Responses',
    'LBL_SHOW_RESPONSES' => 'Show responses',
    'LNK_LIST_SURVEY_RESPONSES' => 'Show Survey Responses',
    'LBL_SURVEY_QUESTION' => 'Question',
    'LBL_SURVEY_TEXT' => 'Text',
    'LBL_SURVEY_TYPE' => 'Type',
    'LBL_SURVEY_ACTIONS' => 'Actions',
    'LBL_SURVEY_NEW_QUESTION' => 'New Question',
    'LBL_SURVEY_RESPONSES' => 'New Question',
    'LBL_SURVEYS_SENT' => 'Surveys Sent:',
    'LBL_SURVEY_DISTINCT' => 'Distinct Surveys Sent:',
    'LBL_DRAFT' => 'Draft',
    'LBL_SUBMIT' => 'Submit',
    'LBL_STARS' => 'Stars'
);
